@@ -113,7 +113,7 @@ function SB_fireNotification(aItem)
 
 var sbCaptureTask = {
 
-	get INTERVAL() { return 3; },
+	get INTERVAL() { return 1; },
 	get LISTBOX()  { return document.getElementById("sbCaptureListbox"); },
 	get STRING()   { return document.getElementById("sbCaptureString"); },
 	get URL()      { return gURLs[this.index]; },
@@ -123,7 +123,7 @@ var sbCaptureTask = {
 	isDocument  : false,
 	canRefresh  : true,
 	sniffer     : null,
-	seconds     : 3,
+	seconds     : 5,
 	timerID     : 0,
 	forceExit   : 0,
 
@@ -650,7 +650,8 @@ sbHeaderSniffer.prototype = {
 			this._channel = sbCommonUtils.IO.newChannelFromURI(this._URL).QueryInterface(Components.interfaces.nsIHttpChannel);
 			this._channel.loadFlags = this._channel.LOAD_BYPASS_CACHE;
 			this._channel.setRequestHeader("User-Agent", navigator.userAgent, false);
-			if ( this.refURLSpec ) this._channel.setRequestHeader("Referer", this.refURLSpec, false);
+			if (this.refURLSpec && this.refURLSpec.indexOf("http") == 0)
+				this._channel.setRequestHeader("Referer", this.refURLSpec, false);
 		} catch(ex) {
 			this.onHttpError("Invalid URL");
 		}
